Sampling
========

.. currentmodule:: torchio.data


Samplers
--------

:class:`ImageSampler`
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: ImageSampler
    :members:
    :show-inheritance:


:class:`LabelSampler`
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: LabelSampler
    :members:
    :show-inheritance:


:class:`GridSampler`
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: GridSampler
    :members:
    :show-inheritance:


Aggregator
----------

:class:`GridAggregator`
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: GridAggregator
    :members:
